==> netrecon-1.78.tgz: netrecon-1.78/prog.h <==

/*
 * prog.h
 *
 * Copyright (c) 2010 Jay Fink <jay.fink@gmail.com>
 * See COPYING file for details
 */

#ifndef MOD_H
#define MOD_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/time.h>
#include <pcap.h>
#include <netinet/in_systm.h>
#include <netinet/in.h>
#include <netinet/ip.h>
#ifndef NETBSD
#include <net/ethernet.h>
#endif
#include <netinet/ip_icmp.h>
#include <netinet/udp.h>
#include <signal.h>
#include <math.h>
#include <unistd.h>
#include <arpa/inet.h>
#include <sys/socket.h>
#include <netdb.h>
#include <semaphore.h>
#include <fcntl.h>
#include <getopt.h>
#include <errno.h>
#include <getopt.h>
#include <net/if.h>
#ifdef NETBSD
#include <net/if_ether.h>
#endif
#include <sys/ioctl.h>
#include <time.h>


struct prog {
	char	*name;
	int	type;
	int	(*main)(int argc, char *argv[]);
};

/* 
 * Program types
 * DO NOT DEFINE A NEW TYPE unless absolutely required.
 */
#define PROG_TYPE_SCAN	0x16	/* scan and scan6 */
#define PROG_TYPE_PCAP	0x32	/* passive scan, tcpdump and arpsniff */

/*
 * Shared Program data, types and definitions
 * 
 * XXX Put specific header data, types and defines to share here
 */ 

/**** PCAP PROGRAM TYPE SHARED HEADER DATA ****/

/* TCP v4 header */
struct tcphdr4 {
    uint16_t th_sport;
    uint16_t th_dport;
    uint32_t th_seq;
    uint32_t th_ack;
#  if __BYTE_ORDER == __LITTLE_ENDIAN
    uint16_t res1:4;
    uint16_t doff:4;
    uint16_t fin:1;
    uint16_t syn:1;
    uint16_t rst:1;
    uint16_t psh:1;
    uint16_t ack:1;
    uint16_t urg:1;
    uint16_t res2:2;
#  elif __BYTE_ORDER == __BIG_ENDIAN
    uint16_t doff:4;
    uint16_t res1:4;
    uint16_t res2:2;
    uint16_t urg:1;
    uint16_t ack:1;
    uint16_t psh:1;
    uint16_t rst:1;
    uint16_t syn:1;
    uint16_t fin:1;
#  else
#   error "Adjust your <bits/endian.h> defines"
#  endif
    uint16_t th_win;
    uint16_t check;
    uint16_t urg_ptr;
};

#define ARP_REQUEST 1
#define ARP_RERPLY 2

typedef struct nr_arphdr {
    u_int16_t hwtype;
    u_int16_t proto;
    u_char hwlen;
    u_char proto_len;
    u_int16_t opcode;
    u_char sender_hwaddr[6];
    u_char sender_ipaddr[4];
    u_char target_hwaddr[6];
    u_char target_ipaddr[4];
} arphdr_t;

typedef struct ether_header eth_hdr; /* Ethernet header */
typedef struct ip ip4ip;             /* IP data         */
typedef struct tcphdr4 tcp_hdr;      /* TCP header      */

char * pcap_dev; /* For scan_passive and netdump */
short int pcap_proto_version;	/* protocol version */
short int pcap_decode_flag;	/* do we wish to decode packets? */

/**** SCAN PROGRAM HEADER DATA ****/
#define PORTMAX 65535
#define DEFAULT_START_PORT 1    /* default starting port to scan */
#define DEFAULT_END_PORT 1024   /* default ending port to scan */
#define DEFAULT_INET_TIMEOUT 2  /* default AF_INET connect timeout */


/**** PROG_PASSIVE ****/
#define IPV4CW 16	/* IPv4 len */
#define PORT_THRESHOLD_DEFAULT 16 /* Set for small networks */
#define NPOLLS_DEFAULT 64 /* Very short passive scan */


/**** USAGE Strings for all registered programs ****/
#define SCAN_USAGE "netrecon scan --ping --conn --dgram --port n-N --time s.ms --extra -V {target}"
#define SCAN6_USAGE "netrecon scan6 --dgram --port N {ipv6addr}"
#ifndef SCAN
#define ARPSNIFF_USAGE "netrecon arpsniff --if <dev> --polls <count> --decode {pcap-expr}"
#define PASSIVE_USAGE "netrecon passive --if <dev> --threshold <n> --polls <count> --extra {pcap-expr}"
#define TCPDUMP_USAGE "netrecon tcpdump --if <dev> --polls <count> --decode {pcap-expr}"
#endif
#endif /* MOD_H */

==> netrecon-1.79.tgz: netrecon-1.79/prog.h <==

/*
 * prog.h
 *
 * Copyright (c) 2010 Jay Fink <jay.fink@gmail.com>
 * See COPYING file for details
 */

#ifndef MOD_H
#define MOD_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <sys/time.h>
#include <pcap.h>
#include <netinet/in_systm.h>
#include <netinet/in.h>
#include <netinet/ip.h>
#ifndef NETBSD
#include <net/ethernet.h>
#endif
#include <netinet/ip_icmp.h>
#include <netinet/udp.h>
#include <signal.h>
#include <math.h>
#include <unistd.h>
#include <arpa/inet.h>
#include <sys/socket.h>
#include <netdb.h>
#include <semaphore.h>
#include <fcntl.h>
#include <getopt.h>
#include <errno.h>
#include <getopt.h>
#include <net/if.h>
#ifdef NETBSD
#include <net/if_ether.h>
#endif
#include <sys/ioctl.h>
#include <time.h>


struct prog {
	char	*name;
	int	type;
	int	(*main)(int argc, char *argv[]);
};

/* 
 * Program types
 * DO NOT DEFINE A NEW TYPE unless absolutely required.
 */
#define PROG_TYPE_SCAN	0x16	/* scan and scan6 */
#define PROG_TYPE_PCAP	0x32	/* passive scan, tcpdump and arpsniff */

/*
 * Shared Program data, types and definitions
 * 
 * XXX Put specific header data, types and defines to share here
 */ 

/**** PCAP PROGRAM TYPE SHARED HEADER DATA ****/

/* TCP v4 header */
struct tcphdr4 {
    uint16_t th_sport;
    uint16_t th_dport;
    uint32_t th_seq;
    uint32_t th_ack;
#  if __BYTE_ORDER == __LITTLE_ENDIAN
    uint16_t res1:4;
    uint16_t doff:4;
    uint16_t fin:1;
    uint16_t syn:1;
    uint16_t rst:1;
    uint16_t psh:1;
    uint16_t ack:1;
    uint16_t urg:1;
    uint16_t res2:2;
#  elif __BYTE_ORDER == __BIG_ENDIAN
    uint16_t doff:4;
    uint16_t res1:4;
    uint16_t res2:2;
    uint16_t urg:1;
    uint16_t ack:1;
    uint16_t psh:1;
    uint16_t rst:1;
    uint16_t syn:1;
    uint16_t fin:1;
#  else
#   error "Adjust your <bits/endian.h> defines"
#  endif
    uint16_t th_win;
    uint16_t check;
    uint16_t urg_ptr;
};

#define ARP_REQUEST 1
#define ARP_RERPLY 2

typedef struct nr_arphdr {
    u_int16_t hwtype;
    u_int16_t proto;
    u_char hwlen;
    u_char proto_len;
    u_int16_t opcode;
    u_char sender_hwaddr[6];
    u_char sender_ipaddr[4];
    u_char target_hwaddr[6];
    u_char target_ipaddr[4];
} arphdr_t;

typedef struct ether_header eth_hdr; /* Ethernet header */
typedef struct ip ip4ip;             /* IP data         */
typedef struct tcphdr4 tcp_hdr;      /* TCP header      */

char * pcap_dev; /* For scan_passive and netdump */
short int pcap_proto_version;	/* protocol version */
short int pcap_decode_flag;	/* do we wish to decode packets? */

/**** SCAN PROGRAM HEADER DATA ****/
#define PORTMAX 65535
#define DEFAULT_START_PORT 1    /* default starting port to scan */
#define DEFAULT_END_PORT 1024   /* default ending port to scan */
#define DEFAULT_INET_TIMEOUT 2  /* default AF_INET connect timeout */


/**** PROG_PASSIVE ****/
#define IPV4CW 16	/* IPv4 len */
#define PORT_THRESHOLD_DEFAULT 16 /* Set for small networks */
#define NPOLLS_DEFAULT 64 /* Very short passive scan */


/**** USAGE Strings for all registered programs ****/
#define SCAN_USAGE "netrecon scan --ping --conn --dgram --port n-N --time s.ms --extra -V {target}"
#define SCAN6_USAGE "netrecon scan6 --dgram --port N {ipv6addr}"
#ifndef SCAN
#define ARPSNIFF_USAGE "netrecon arpsniff --if <dev> --polls <count> --decode {pcap-expr}"
#define PASSIVE_USAGE "netrecon passive --if <dev> --threshold <n> --polls <count> --extra --no-verify {pcap-expr}"
#define TCPDUMP_USAGE "netrecon tcpdump --if <dev> --polls <count> --decode {pcap-expr}"
#endif
#endif /* MOD_H */
